@@ -1,7 +1,7 @@
 from collections import defaultdict
 from copy import deepcopy
 from datetime import datetime, timedelta, timezone
-from typing import Any, Dict, Iterable, List, Optional, Tuple
+from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
 from requests import Request
 
@@ -21,7 +21,6 @@ from ..models.iot import (
 )
 from ..utils import is_datetime_aware, make_logger
 from ..utils.object_mapper import ObjectMapper
-from ..utils.orgs import get_slug_or_org_id
 from .api import ApiEnvironment, ConfiguredApi
 from .pagination import DataPoint, PagedRecords, PagedTimeSeries, PageOptions
 
@@ -50,10 +49,9 @@ class IotService(ConfiguredApi):
         ),
     )
 
-    def __init__(self, auth: Auth, org_id: str, env: str = "production", **kwargs) -> None:
+    def __init__(self, auth: Auth, org_slug: str, env: str = "production", **kwargs) -> None:
         super().__init__(env=env, auth=auth, **kwargs)
-        tenant = get_slug_or_org_id(org_id)
-        self.base_url = self.base_url.format(tenant=tenant)
+        self.base_url = self.base_url.format(tenant=org_slug)
 
     def provision_field_for_feed(self, feed_id: int, field: Field) -> Field:
         resp = self.post(f"feeds/{feed_id}/fields", data=field.post())
@@ -107,6 +105,10 @@ class IotService(ConfiguredApi):
             return feeds[0]  # type: ignore
         raise KeyError(f"Expected singleton feed with key {key}, not {N}")
 
+    def update_feed_provisioning_mode(self, id: int, enabled: bool):
+        """Enable/Disable provisioning mode for a feed"""
+        return self.put(uri=f"feeds/{id}", json={"provisioning_mode": enabled})
+
     def get_feeds(
         self,
         facility_id: Optional[int] = None,
@@ -150,7 +152,7 @@ class IotService(ConfiguredApi):
     def get_time_series_for_field(
         self,
         field: Field,
-        start_time: datetime = None,
+        start_time: Union[datetime, None] = None,
         window: Window = Window.RAW,
         end_time: Optional[datetime] = None,
         per_page: int = 1000,
@@ -176,7 +178,7 @@ class IotService(ConfiguredApi):
     def get_time_series_for_fields(
         self,
         fields: List[Field],
-        start_time: datetime = None,
+        start_time: Union[datetime, None] = None,
         window: Window = Window.RAW,
         end_time: Optional[datetime] = None,
     ) -> List[FieldTimeSeries]:
@@ -445,7 +447,9 @@ class IotDataService(ConfiguredApi):
 
         return responses
 
-    def get_source_field_cursor(self, source_key: str, field_name: str = None) -> Optional[datetime]:
+    def get_source_field_cursor(
+        self, source_key: str, field_name: Union[str, None] = None
+    ) -> Optional[datetime]:
         """Get the cursor for the given source and field"""
 
         url = f"org/{self.org_id}/sources/{source_key}"
